import moment from "moment";
import {Collection} from "../core/database.js";
import {Application,cors} from "../core/http.js";

Application.post("/collection/:catalog/data.json", cors(), ReadCollection);

/**
 * @param {import("express").Request} request 
 * @param {import("express").Response} response 
 */
async function ReadCollection(request, response)
{
    let catalog = request.params.catalog;
    let order = (request.body?.order == "asc" ? "asc" : "desc") || "asc";
    let length = typeof request.body?.length == "number" ? Math.max(1, Math.min(request.query.length, 250)) : 100;
    let page = typeof request.body?.page == "number" ? Math.max(1, request.query.length) : 1;
    let fromtime = typeof request.body?.fromtime == "string" ? parseRelativeTime(request.body.fromtime) : null;

    let build = Collection()
        .where("catalog", catalog)
        .where("expire", ">", moment().toISOString())
        .orderBy("time", order)
        .offset((page - 1) * length)
        .limit(length);

    if(fromtime) build.where("time",">", fromtime);

    let result = await build;

    let responseData = result.map(e => JSON.parse(e.data));

    return response.status(200).json(responseData);
}

function parseRelativeTime(relativeTime) {
    const executedReg = /^(\d+)\s+(minute|hour|day|month|year)+$/g.exec(relativeTime);

    let time = moment().add(executedReg[1], executedReg[2]);
    
    return time.toISOString();
}